@@ -2,7 +2,7 @@ use warnings;
 
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '3.2.2';
+$Git::Hooks::VERSION = '3.3.0';
 use v5.16.0;
 use utf8;
 use Carp;
@@ -257,6 +257,8 @@ sub run_hook {
         } else {
             # ...and return undef when they succeed.
         }
+    } continue {
+        $git->check_timeout();
     }
 
     # Invoke enabled external hooks. This doesn't work in Windows yet.
@@ -265,20 +267,14 @@ sub run_hook {
     # Some hooks want to do some post-processing
     foreach my $post_hook ($git->post_hooks) {
         $post_hook->($hook_basename, $git, @args);
+    } continue {
+        $git->check_timeout();
     }
 
-    if (my $faults = $git->get_faults()) {
-        $log->debug(Environment => {ENV => \%ENV});
-        $faults .= "\n" unless $faults =~ /\n$/;
-        if (($hook_basename eq 'commit-msg' or $hook_basename eq 'pre-commit')
-                and not $git->get_config_boolean(githooks => 'abort-commit')) {
-            $log->warning(Warning => {faults => $faults});
-            carp $faults;
-        } else {
-            $log->error(Error => {faults => $faults});
-            croak $faults;
-        }
-    }
+    $git->fail_on_faults(
+        ($hook_basename eq 'commit-msg' or $hook_basename eq 'pre-commit')
+        and not $git->get_config_boolean(githooks => 'abort-commit')
+    );
 
     return;
 }
@@ -298,7 +294,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 3.2.2
+version 3.3.0
 
 =head1 SYNOPSIS
 
@@ -1603,6 +1599,21 @@ The following commands may give you an idea as to which commands to use:
 This option is similar to the C<githooks.error-header> above, but produces a
 footer to the error messages generated by Git::Hooks, if any.
 
+=head2 error-length-limit INT
+
+This option specifies a limit to the length of the error messages in
+characters. If the errors are bigger than the limit the message is truncated and
+a special mark is appended to the end like this:
+
+  [MESSAGE TRUNCATED AT githooks.error-length-limit]
+
+This is useful to avoid clogging the git server logs. Gerrit, for instance, has
+a configuration named
+L<change.commentSizeLimit|https://gerrit-review.googlesource.com/Documentation/config-gerrit.html#change>
+which specified a limit to the size of change comments, and Git::Hook's error
+messages are usually inserted as comments. So, it's wise to set this option when
+using Gerrit.
+
 =head2 help-on-error MESSAGE
 
 This option allows you to specify a helpful message that will be shown if
@@ -1620,6 +1631,11 @@ This option tells if Git::Hooks's output should be colorized. It accepts the
 same values as Git's own C<color.ui> option. If it's not set, the C<color.ui>
 value is used by default. The meaning of each value is the following:
 
+=head2 timeout SECONDS
+
+This option sets a limit in seconds to how long the hook script can run. It's
+used by the L<Git::Repository::Plugin::GitHooks::check_timeout> method.
+
 =over 4
 
 =item B<never (or false)>
